slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVMatMult

Computes the matrix-vector product for each column, Y=A*V.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVMatMult(BV V,Mat A,BV Y)

Neighbor-wise Collective on A

### Input Parameters

| V | - basis vectors context
| A | - the matrix

### Output Parameter

| Y | - the result

### Notes

Both V and Y must be distributed in the same manner. Only active columns (excluding the leading ones) are processed. In the result Y, columns are overwritten starting from the leading ones. The number of active columns in V and Y should match, although they need not be the same columns.

It is possible to choose whether the computation is done column by column or as a Mat-Mat product, see BVSetMatMultMethod().

### See Also

BVCopy(), BVSetActiveColumns(), BVMatMultColumn(), BVMatMultTranspose(), BVMatMultHermitianTranspose(), BVSetMatMultMethod()

### Level

beginner

### Location

src/sys/classes/bv/interface/bvops.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages